<a href="{% url 'bee_django_crm:preuser_list' %}?level=1">用户管理</a> |
    <a href="{% url 'bee_django_crm:preuser_contract_list' 0%}">用户合同管理</a> |
    <a href="{% url 'bee_django_crm:preuser_fee_list' 0%}">用户缴费管理</a> |
    <a href="{% url 'bee_django_crm:application_question_list' %}">申请表模版管理</a> |
    <a href="{% url 'bee_django_crm:source_list' %}">渠道模版管理</a> |
    <a href="{% url 'bee_django_crm:contract_list' %}">合同模版管理</a> |
{#    <a href="{% url 'bee_django_crm:poster_list' %}">海报管理</a> |#}